Construct a path to download a PDF
make_pdf_dest(url, subd = "")
The file path to which the PDF will be written
Creates the directory to which the PDF will be downloaded if it doesn't yet exist and returns the download path. The filename of the download is based on the URL, but spaces " " are replaced with underscores "_", and the ".pdf" prefix is appended if not present in the URL.